@@ -1,38 +1,37 @@
 package Business::PayPal::API;
-
+$Business::PayPal::API::VERSION = '0.72';
 use 5.008001;
 use strict;
 use warnings;
 
-use SOAP::Lite 0.67; # +trace => 'all';
+use Data::Printer;
+use SOAP::Lite 0.67;    # +trace => 'all';
 use Carp qw(carp);
 
-our $VERSION = '0.70';
-our $CVS_VERSION = '$Id: API.pm,v 1.24 2009/07/28 18:00:58 scott Exp $';
-our $Debug = 0;
+our $Debug = $ENV{WPP_DEBUG} || 0;
 
 ## NOTE: This package exists only until I can figure out how to use
 ## NOTE: SOAP::Lite's WSDL support for complex types and importing
 ## NOTE: type definitions, at which point this module will become much
 ## NOTE: smaller (or non-existent).
 
-sub C_api_sandbox    () { 'https://api.sandbox.paypal.com/2.0/' }
-sub C_api_sandbox_3t () { 'https://api-3t.sandbox.paypal.com/2.0/' }
-sub C_api_live    () { 'https://api.paypal.com/2.0/' }
-sub C_api_live_3t () { 'https://api-3t.paypal.com/2.0/' }
-sub C_xmlns_pp    () { 'urn:ebay:api:PayPalAPI' }
-sub C_xmlns_ebay  () { 'urn:ebay:apis:eBLBaseComponents' }
-sub C_version     () { '3.0' }  ## 3.0 adds RecurringPayments
+sub C_api_sandbox ()    {'https://api.sandbox.paypal.com/2.0/'}
+sub C_api_sandbox_3t () {'https://api-3t.sandbox.paypal.com/2.0/'}
+sub C_api_live ()       {'https://api.paypal.com/2.0/'}
+sub C_api_live_3t ()    {'https://api-3t.paypal.com/2.0/'}
+sub C_xmlns_pp ()       {'urn:ebay:api:PayPalAPI'}
+sub C_xmlns_ebay ()     {'urn:ebay:apis:eBLBaseComponents'}
+sub C_version () {'61.0'}    ## 3.0 adds RecurringPayments
 
 ## this is an inside-out object. Make sure you 'delete' additional
 ## members in DESTROY() as you add them.
 my %Soap;
 my %Header;
 
-my %H_PKCS12File;     ## path to certificate file (pkc12)
-my %H_PKCS12Password; ## password for certificate file (pkc12)
-my %H_CertFile;       ## PEM certificate
-my %H_KeyFile;        ## PEM private key
+my %H_PKCS12File;            ## path to certificate file (pkc12)
+my %H_PKCS12Password;        ## password for certificate file (pkc12)
+my %H_CertFile;              ## PEM certificate
+my %H_KeyFile;               ## PEM private key
 
 sub import {
     my $self    = shift;
@@ -40,23 +39,26 @@ sub import {
 
     for my $module ( @modules ) {
         eval( "use Business::PayPal::API::$module;" );
-        if( $@ ) {
+        if ( $@ ) {
             warn $@;
             next;
         }
 
         ## import 'exported' subroutines into our namespace
         no strict 'refs';
-        for my $sub ( @{"Business::PayPal::API::" . $module . "::EXPORT_OK"} ) {
-            *{"Business::PayPal::API::" . $sub} = *{"Business::PayPal::API::" . $module . "::" . $sub};
+        for my $sub (
+            @{ "Business::PayPal::API::" . $module . "::EXPORT_OK" } )
+        {
+            *{ "Business::PayPal::API::" . $sub }
+                = *{ "Business::PayPal::API::" . $module . "::" . $sub };
         }
     }
 }
 
 sub new {
     my $class = shift;
-    my %args = @_;
-    my $self = bless \(my $fake), $class;
+    my %args  = @_;
+    my $self  = bless \( my $fake ), $class;
 
     ## if you add new args, be sure to update the test file's @variables array
     $args{Username}  ||= '';
@@ -64,35 +66,43 @@ sub new {
     $args{Signature} ||= '';
     $args{Subject}   ||= '';
     $args{sandbox} = 1 unless exists $args{sandbox};
-    $args{timeout}   ||= 0;
+    $args{timeout} ||= 30;
 
     $H_PKCS12File{$self}     = $args{PKCS12File}     || '';
     $H_PKCS12Password{$self} = $args{PKCS12Password} || '';
     $H_CertFile{$self}       = $args{CertFile}       || '';
     $H_KeyFile{$self}        = $args{KeyFile}        || '';
 
-    my $proxy = ($args{sandbox}
-		 ? ($args{Signature}
-                    ? C_api_sandbox_3t
-                    : C_api_sandbox)
-		 : ($args{Signature}
-		    ? C_api_live_3t
-		    : C_api_live)
-		);
+    my $proxy = (
+        $args{sandbox}
+        ? ( $args{Signature}
+            ? C_api_sandbox_3t
+            : C_api_sandbox
+            )
+        : ( $args{Signature}
+            ? C_api_live_3t
+            : C_api_live
+        )
+    );
 
-    $Soap{$self} = SOAP::Lite->proxy( $proxy, timeout => $args{timeout} )->uri( C_xmlns_pp );
+    $Soap{$self} = SOAP::Lite->proxy( $proxy, timeout => $args{timeout} )
+        ->uri( C_xmlns_pp );
 
-    $Header{$self} = SOAP::Header
-      ->name( RequesterCredentials => \SOAP::Header->value
-	      ( SOAP::Data->name( Credentials => \SOAP::Data->value
-				  ( SOAP::Data->name( Username  => $args{Username} )->type(''),
-				    SOAP::Data->name( Password  => $args{Password} )->type(''),
-				    SOAP::Data->name( Signature => $args{Signature} )->type(''),
-				    SOAP::Data->name( Subject   => $args{Subject} )->type(''),
-				  ),
-				)->attr( {xmlns => C_xmlns_ebay} )
-	      )
-	    )->attr( {xmlns => C_xmlns_pp} )->mustUnderstand(1);
+    $Header{$self} = SOAP::Header->name(
+        RequesterCredentials => \SOAP::Header->value(
+            SOAP::Data->name(
+                Credentials => \SOAP::Data->value(
+                    SOAP::Data->name( Username => $args{Username} )
+                        ->type( '' ),
+                    SOAP::Data->name( Password => $args{Password} )
+                        ->type( '' ),
+                    SOAP::Data->name( Signature => $args{Signature} )
+                        ->type( '' ),
+                    SOAP::Data->name( Subject => $args{Subject} )->type( '' ),
+                ),
+            )->attr( { xmlns => C_xmlns_ebay } )
+        )
+    )->attr( { xmlns => C_xmlns_pp } )->mustUnderstand( 1 );
 
     return $self;
 }
@@ -108,57 +118,61 @@ sub DESTROY {
     delete $H_CertFile{$self};
     delete $H_KeyFile{$self};
 
-    my $super = $self->can("SUPER::DESTROY");
+    my $super = $self->can( "SUPER::DESTROY" );
     goto &$super if $super;
 }
 
 sub version_req {
-    return SOAP::Data->name( Version => C_version )
-      ->type('xs:string')->attr( {xmlns => C_xmlns_ebay} );
+    return SOAP::Data->name( Version => C_version )->type( 'xs:string' )
+        ->attr( { xmlns => C_xmlns_ebay } );
 }
 
 sub doCall {
-    my $self = shift;
+    my $self        = shift;
     my $method_name = shift;
-    my $request = shift;
-    my $method = SOAP::Data->name( $method_name )->attr( {xmlns => C_xmlns_pp} );
+    my $request     = shift;
+    my $method
+        = SOAP::Data->name( $method_name )->attr( { xmlns => C_xmlns_pp } );
 
     my $som;
     {
-        $H_PKCS12File{$self}     and local $ENV{HTTPS_PKCS12_FILE}     = $H_PKCS12File{$self};
-        $H_PKCS12Password{$self} and local $ENV{HTTPS_PKCS12_PASSWORD} = $H_PKCS12Password{$self};
-        $H_CertFile{$self}       and local $ENV{HTTPS_CERT_FILE}       = $H_CertFile{$self};
-        $H_KeyFile{$self}        and local $ENV{HTTPS_KEY_FILE}        = $H_KeyFile{$self};
+        $H_PKCS12File{$self}
+            and local $ENV{HTTPS_PKCS12_FILE} = $H_PKCS12File{$self};
+        $H_PKCS12Password{$self}
+            and local $ENV{HTTPS_PKCS12_PASSWORD} = $H_PKCS12Password{$self};
+        $H_CertFile{$self}
+            and local $ENV{HTTPS_CERT_FILE} = $H_CertFile{$self};
+        $H_KeyFile{$self} and local $ENV{HTTPS_KEY_FILE} = $H_KeyFile{$self};
 
-	if( $Debug ) {
-	    print STDERR SOAP::Serializer->envelope(method => $method,
-                                                    $Header{$self}, $request), "\n";
-	}
+        if ( $Debug ) {
+            print STDERR SOAP::Serializer->envelope(
+                method => $method,
+                $Header{$self}, $request
+                ),
+                "\n";
+        }
 
-#	$Soap{$self}->readable( $Debug );
-#	$Soap{$self}->outputxml( $Debug );
-
-	no warnings 'redefine';
-	local *SOAP::Deserializer::typecast = sub {shift; return shift};
+        no warnings 'redefine';
+        local *SOAP::Deserializer::typecast = sub { shift; return shift };
         eval {
-          $som = $Soap{$self}->call( $Header{$self}, $method => $request );
+            $som = $Soap{$self}->call( $Header{$self}, $method => $request );
         };
 
-        if( $@ ) {
-          carp $@;
-          return;
+        if ( $@ ) {
+            carp $@;
+            return;
         }
     }
 
-    if( $Debug ) {
+    if ( $Debug ) {
         ## FIXME: would be nicer to dump a SOM to XML, but how to do that?
-        require Data::Dumper;
-        print STDERR Data::Dumper::Dumper($som->envelope);
+        p( $som->envelope );
     }
 
-    if( ref($som) && $som->fault ) {
-        carp "Fault: " . $som->faultstring 
-          . ( $som->faultdetail ? " (" . $som->faultdetail . ")" : '' ) 
+    if ( ref( $som ) && $som->fault ) {
+        carp "Fault: "
+            . $som->faultstring
+            . ( $som->faultdetail ? " (" . $som->faultdetail . ")" : '' )
             . "\n";
         return;
     }
@@ -167,27 +181,28 @@ sub doCall {
 }
 
 sub getFieldsList {
-    my $self = shift;
-    my $som  = shift;
-    my $path = shift;
+    my $self   = shift;
+    my $som    = shift;
+    my $path   = shift;
     my $fields = shift;
 
     return unless $som;
 
     my %trans_id = ();
-    my @records = ();
-    for my $rec ( $som->valueof($path) ) {
+    my @records  = ();
+    for my $rec ( $som->valueof( $path ) ) {
         my %response = ();
-        @response{keys %$fields} = @{$rec}{keys %$fields};
+        @response{ keys %$fields } = @{$rec}{ keys %$fields };
 
         ## avoid duplicates
-	if( defined $response{TransactionID}) {
-	    if( $trans_id{$response{TransactionID}}) {
-		next;
-	    } else {	
-		$trans_id{$response{TransactionID}} = 1;
-	    }
-	}
+        if ( defined $response{TransactionID} ) {
+            if ( $trans_id{ $response{TransactionID} } ) {
+                next;
+            }
+            else {
+                $trans_id{ $response{TransactionID} } = 1;
+            }
+        }
         push @records, \%response;
     }
 
@@ -195,11 +210,11 @@ sub getFieldsList {
 }
 
 sub getFields {
-    my $self = shift;
-    my $som  = shift;
-    my $path = shift;
+    my $self     = shift;
+    my $som      = shift;
+    my $path     = shift;
     my $response = shift;
-    my $fields = shift;
+    my $fields   = shift;
 
     return unless $som;
 
@@ -223,10 +238,10 @@ sub getFields {
     ## it.
 
     for my $field ( keys %$fields ) {
-        my @vals = grep { defined } $som->valueof("$path/$fields->{$field}");
+        my @vals = grep {defined} $som->valueof( "$path/$fields->{$field}" );
         next unless @vals;
 
-        if( scalar(@vals) == 1 ) {
+        if ( scalar( @vals ) == 1 ) {
             $response->{$field} = $vals[0];
         }
         else {
@@ -236,33 +251,36 @@ sub getFields {
 }
 
 sub getBasic {
-    my $self = shift;
-    my $som  = shift;
-    my $path = shift;
+    my $self    = shift;
+    my $som     = shift;
+    my $path    = shift;
     my $details = shift;
 
     return unless $som;
 
     for my $field ( qw( Ack Timestamp CorrelationID Version Build ) ) {
-        $details->{$field} = $som->valueof("$path/$field") || '';
+        $details->{$field} = $som->valueof( "$path/$field" ) || '';
     }
 
     return $details->{Ack} =~ /Success/;
 }
 
 sub getErrors {
-    my $self = shift;
-    my $som  = shift;
-    my $path = shift;
+    my $self    = shift;
+    my $som     = shift;
+    my $path    = shift;
     my $details = shift;
 
     return unless $som;
 
     my @errors = ();
 
-    for my $enode ( $som->valueof("$path/Errors") ) {
-        push @errors, { LongMessage => $enode->{LongMessage},
-                        ErrorCode   => $enode->{ErrorCode}, };
+    for my $enode ( $som->valueof( "$path/Errors" ) ) {
+        push @errors,
+            {
+            LongMessage => $enode->{LongMessage},
+            ErrorCode   => $enode->{ErrorCode},
+            };
     }
     $details->{Errors} = \@errors;
 
@@ -270,48 +288,62 @@ sub getErrors {
 }
 
 1;
+
+# ABSTRACT: PayPal SOAP API client with sandbox support
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Business::PayPal::API - PayPal API
+Business::PayPal::API - PayPal SOAP API client with sandbox support
+
+=head1 VERSION
+
+version 0.72
 
 =head1 SYNOPSIS
 
-  use Business::PayPal::API qw( ExpressCheckout GetTransactionDetails );
+    use Business::PayPal::API qw( ExpressCheckout GetTransactionDetails );
 
-  ## certificate authentication
-  my $pp = new Business::PayPal::API
-            ( Username       => 'my_api1.domain.tld',
-              Password       => 'this_is_my_password',
-              PKCS12File     => '/path/to/cert.pkcs12',
-              PKCS12Password => '(pkcs12 password)',
-              sandbox        => 1 );
+    ## certificate authentication
+    my $pp = Business::PayPal::API->new(
+        Username       => 'my_api1.domain.tld',
+        Password       => 'this_is_my_password',
+        PKCS12File     => '/path/to/cert.pkcs12',
+        PKCS12Password => '(pkcs12 password)',
+        sandbox        => 1,
+    );
 
-  ## PEM cert authentication
-  my $pp = new Business::PayPal::API
-            ( Username    => 'my_api1.domain.tld',
-              Password    => 'this_is_my_password',
-              CertFile    => '/path/to/cert.pem',
-              KeyFile     => '/path/to/cert.pem',
-              sandbox     => 1 );
+    ## PEM cert authentication
+    my $pp = Business::PayPal::API->new(
+        Username => 'my_api1.domain.tld',
+        Password => 'this_is_my_password',
+        CertFile => '/path/to/cert.pem',
+        KeyFile  => '/path/to/cert.pem',
+        sandbox  => 1,
+    );
 
-  ## 3-token (Signature) authentication
-  my $pp = new Business::PayPal::API
-            ( Username   => 'my_api1.domain.tld',
-              Password   => 'Xdkis9k3jDFk39fj29sD9',  ## supplied by PayPal
-              Signature  => 'f7d03YCpEjIF3s9Dk23F2V1C1vbYYR3ALqc7jm0UrCcYm-3ksdiDwjfSeii',  ## ditto
-              sandbox    => 1 );
-
-  my %response = $pp->SetExpressCheckout( ... );
+    ## 3-token (Signature) authentication
+    my $pp = Business::PayPal::API->new(
+        Username => 'my_api1.domain.tld',
+        Password => 'Xdkis9k3jDFk39fj29sD9',    ## supplied by PayPal
+        Signature =>
+            'f7d03YCpEjIF3s9Dk23F2V1C1vbYYR3ALqc7jm0UrCcYm-3ksdiDwjfSeii', ## ditto
+        sandbox => 1,
+    );
 
+    my %response = $pp->SetExpressCheckout( ... );
 
 =head1 DESCRIPTION
 
 B<Business::PayPal::API> supports both certificate authentication and
 the new 3-token "Signature" authentication.
 
-It also support PayPal's development I<sandbox> for testing. See the
+It also supports PayPal's development I<sandbox> for testing. See the
 B<sandbox> parameter to B<new()> below for details.
 
 B<Business::PayPal::API> can import other B<API> derived classes:
@@ -322,13 +354,13 @@ This allows for much more concise and intuitive usage. For example,
 these two statements are equivalent:
 
   use Business::PayPal::API::RefundTransaction;
-  my $pp = new Business::PayPal::API::RefundTransaction( ... );
+  my $pp = Business::PayPal::API::RefundTransaction->new( ... );
   $pp->RefundTransaction( ... );
 
 and more concisely:
 
   use Business::PayPal::API qw( RefundTransaction );
-  my $pp = new Business::PayPal::API( ... );
+  my $pp = Business::PayPal::API->new( ... );
   $pp->RefundTransaction( ... );
 
 The advantage of this becomes clear when you need to use multiple API
@@ -337,10 +369,10 @@ invoke the various methods, instead of creating a new object for each
 subclass. Here is an example of a B<API> object used to invoke various
 PayPal APIs with the same object:
 
-  use Business::PayPal::API qw( GetTransactionDetails 
-                                TransactionSearch 
+  use Business::PayPal::API qw( GetTransactionDetails
+                                TransactionSearch
                                 RefundTransaction );
-  my $pp = new Business::PayPal::API( ... );
+  my $pp = Business::PayPal::API->new( ... );
   my $records = $pp->TransactionSearch( ... );
 
   my %details = $pp->GetTransactionDetails( ... );
@@ -465,6 +497,10 @@ L<https://www.paypal.com/IntegrationCenter/ic_sandbox.html>
 
 =back
 
+=head1 NAME
+
+Business::PayPal::API - PayPal API
+
 =head1 ERROR HANDLING
 
 Every API call should return an B<Ack> response, whether I<Success>,
@@ -549,11 +585,14 @@ sure:
 
    * your username and password match those found in your PayPal
      Business account sandbox (this is not the same as your regular
-     account.
+     account).
 
    * you're not trying to use your live username and password for
      sandbox testing and vice versa.
 
+   * you are using a US Business Sandbox account, you may also need to have
+     "PayPal Payments Pro" enabled.
+
    * if the sandbox works but "live" does not, make sure you've turned
      off the 'sandbox' parameter correctly. Otherwise you'll be
      passing your PayPal sandbox credentials to PayPal's live site
@@ -573,12 +612,12 @@ sure:
 
          ## delete all HTTPS, SSL env
          delete $ENV{$_} for grep { /^(HTTPS|SSL)/ } keys %ENV;
-         
+
          ## now put our own HTTPS env back in
          $ENV{HTTPS_CERT_FILE} = '/var/path/to/cert.pem';
-         
+
          ## create our paypal object
-         my $pp = new Business::PayPal::API...
+         my $pp = Business::PayPal::API->new(...)
 
    * if you have already loaded Net::SSLeay (or IO::Socket::SSL), then
      Net::HTTPS will prefer to use IO::Socket::SSL. I don't know how
@@ -634,7 +673,7 @@ arguments:
 =head1 DEBUGGING
 
 You can see the raw SOAP XML sent and received by
-B<Business::PayPal::API> by setting it's B<$Debug> variable:
+B<Business::PayPal::API> by setting its B<$Debug> variable:
 
   $Business::PayPal::API::Debug = 1;
   $pp->SetExpressCheckout( %args );
@@ -683,14 +722,14 @@ That is, B<Business::PayPal::API> will import any subroutine into its
 own namespace from the B<@EXPORT_OK> array. Now it can be used like this:
 
   use Business::PayPal::API qw( SomeAPI );
-  my $pp = new Business::PayPal::API( ... );
+  my $pp = Business::PayPal::API->new( ... );
   $pp->SomeAPIMethod( ... );
 
 Of course, we also do a 'use Business::PayPal::API' in the module so
 that it can be used as a standalone module, if necessary:
 
   use Business::PayPal::API::SomeAPI;
-  my $pp = new Business::PayPal::API::SomeAPI( ... ); ## same args as superclass
+  my $pp = Business::PayPal::API::SomeAPI->new( ... ); ## same args as superclass
   $pp->SomeAPIMethod( ... );
 
 Adding the B<@EXPORT_OK> array in your module allows your module to be
@@ -720,7 +759,7 @@ and are safe to use).
 
 As with all web services, if PayPal stop supporting their API
 endpoint, this module *may stop working*. You can help me keep this
-module up-to-date if you notice such an event occuring.
+module up-to-date if you notice such an event occurring.
 
 Also, I didn't implement a big fat class hierarchy to make this module
 "academically" correct. You'll notice that I fudged colliding
@@ -743,9 +782,6 @@ module in some way:
 for authoring the AuthorizationRequest, CaptureRequest,
 DirectPayments, ReauthorizationRequest, and VoidRequest extensions.
 
-Danny's contact information may be found in the AUTHOR section of the
-above modules.
-
 =item * <jshiles at base16consulting daught com>
 
 for finding some API typos in the ExpressCheckout API
@@ -789,16 +825,29 @@ L<https://www.paypal.com/IntegrationCenter/ic_expresscheckout.html>,
 L<https://www.sandbox.paypal.com/en_US/pdf/PP_Sandbox_UserGuide.pdf>,
 L<https://developer.paypal.com/en_US/pdf/PP_APIReference.pdf>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Scott Wiersdorf, E<lt>scott@perlcode.orgE<gt>
+=over 4
+
+=item *
+
+Scott Wiersdorf <scott@perlcode.org>
+
+=item *
+
+Danny Hembree <danny@dynamical.org>
+
+=item *
+
+Bradley M. Kuhn <bkuhn@ebb.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006, 2007 by Scott Wiersdorf
+This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.6 or,
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
