@@ -1,16 +1,15 @@
 package Business::PayPal::API::CaptureRequest;
-
+$Business::PayPal::API::CaptureRequest::VERSION = '0.72';
 use 5.008001;
 use strict;
 use warnings;
 
 use SOAP::Lite 0.67;
+
 #use SOAP::Lite +trace => 'debug';
 use Business::PayPal::API ();
 
-our @ISA = qw(Business::PayPal::API);
-our $VERSION = '0.11';
-our $CVS_VERSION = '$Id: CaptureRequest.pm,v 1.2 2007/10/16 19:09:26 scott Exp $';
+our @ISA       = qw(Business::PayPal::API);
 our @EXPORT_OK = qw(DoCaptureRequest);
 
 sub DoCaptureRequest {
@@ -18,77 +17,88 @@ sub DoCaptureRequest {
     my %args = @_;
 
     my %types = (
-          AuthorizationID => 'xs:string',
+        AuthorizationID => 'xs:string',
+
 #The inclusion of the "ebl:CompleteCodeType" here, or any other reasonable type,
 #causes and error. Assigning a null string allows the module to work normally
 #with the exception that testing for "Success" fails, one must test for not
 #being a "Failure"... there may be a life lesson here.
-          CompleteType    => '',
-          Amount          => 'ebl:BasicAmountType',
-          Note            => 'xs:string',
-          );
+        CompleteType => '',
+        Amount       => 'ebl:BasicAmountType',
+        Note         => 'xs:string',
+    );
 
-    $args{currencyID} ||= 'USD';
+    $args{currencyID}   ||= 'USD';
     $args{CompleteType} ||= 'Complete';
 
-    my @ref_trans = 
-      (
-       $self->version_req,
-       SOAP::Data->name( AuthorizationID => $args{AuthorizationID} )->type($types{AuthorizationID}),
-       SOAP::Data->name( CompleteType => $args{CompleteType} )->type($types{CompleteType}),
-      );
+    my @ref_trans = (
+        $self->version_req,
+        SOAP::Data->name( AuthorizationID => $args{AuthorizationID} )
+            ->type( $types{AuthorizationID} ),
+        SOAP::Data->name( CompleteType => $args{CompleteType} )
+            ->type( $types{CompleteType} ),
+    );
 
-    if( $args{Amount} ) {
-    push @ref_trans,
-      SOAP::Data->name( Amount => $args{Amount} )
-          ->type( $types{Amount} )
-            ->attr( { currencyID => $args{currencyID} } )
+    if ( $args{Amount} ) {
+        push @ref_trans,
+            SOAP::Data->name( Amount => $args{Amount} )
+            ->type( $types{Amount} )
+            ->attr( { currencyID => $args{currencyID} } );
     }
 
-    my $request = SOAP::Data->name
-      ( DoCaptureRequest => \SOAP::Data->value( @ref_trans ) )
-            ->type("ns:DoCaptureRequestType");
+    my $request
+        = SOAP::Data->name(
+        DoCaptureRequest => \SOAP::Data->value( @ref_trans ) )
+        ->type( "ns:DoCaptureRequestType" );
 
     my $som = $self->doCall( DoCaptureReq => $request )
-      or return;
+        or return;
 
     my $path = '/Envelope/Body/DoCaptureResponse';
 
     my %response = ();
-    unless( $self->getBasic($som, $path, \%response) ) {
-        $self->getErrors($som, $path, \%response);
+    unless ( $self->getBasic( $som, $path, \%response ) ) {
+        $self->getErrors( $som, $path, \%response );
         return %response;
     }
     $path .= '/DoCaptureResponseDetails/PaymentInfo';
-    $self->getFields($som, $path, \%response,
-                     { 
-                     TransactionID   => 'TransactionID',
-                     ParentTransactionID => 'ParentTransactionID',
-                     ReceiptID       => 'ReceiptID',
-                     TransactionType => 'TransactionType',
-                     PaymentType     => 'PaymentType',
-                     PaymentDate     => 'PaymentDate',
-                     GrossAmount     => 'GrossAmount',
-                     FeeAmount       => 'FeeAmount',
-                     SettleAmount    => 'SettleAmount',
-                     TaxAmount       => 'TaxAmount',
-                     ExchangeRate    => 'ExchangeRate',
-                     PaymentStatus   => 'PaymentStatus',
-                     PendingReason   => 'PendingReason',
-                     ReasonCode      => 'ReasonCode',
-                     }
-                    );
+    $self->getFields(
+        $som, $path,
+        \%response,
+        {   TransactionID       => 'TransactionID',
+            ParentTransactionID => 'ParentTransactionID',
+            ReceiptID           => 'ReceiptID',
+            TransactionType     => 'TransactionType',
+            PaymentType         => 'PaymentType',
+            PaymentDate         => 'PaymentDate',
+            GrossAmount         => 'GrossAmount',
+            FeeAmount           => 'FeeAmount',
+            SettleAmount        => 'SettleAmount',
+            TaxAmount           => 'TaxAmount',
+            ExchangeRate        => 'ExchangeRate',
+            PaymentStatus       => 'PaymentStatus',
+            PendingReason       => 'PendingReason',
+            ReasonCode          => 'ReasonCode',
+        }
+    );
 
     return %response;
 }
 
 1;
-__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Business::PayPal::API::CaptureRequest - PayPal CaptureRequest API
 
+=head1 VERSION
+
+version 0.72
+
 =head1 SYNOPSIS
 
   use Business::PayPal::API::CaptureRequest;
@@ -154,17 +164,34 @@ None by default.
 
 L<https://developer.paypal.com/en_US/pdf/PP_APIReference.pdf>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Danny Hembree E<lt>danny-hembree@dynamical.orgE<gt>
+=over 4
+
+=item *
+
+Scott Wiersdorf <scott@perlcode.org>
+
+=item *
+
+Danny Hembree <danny@dynamical.org>
+
+=item *
+
+Bradley M. Kuhn <bkuhn@ebb.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Danny Hembree
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.5 or,
-at your option, any later version of Perl 5 you may have available.
+This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+# ABSTRACT: PayPal CaptureRequest API
+
