@@ -1,5 +1,5 @@
 package Business::PayPal::API::MassPay;
-
+$Business::PayPal::API::MassPay::VERSION = '0.72';
 use 5.008001;
 use strict;
 use warnings;
@@ -7,9 +7,7 @@ use warnings;
 use SOAP::Lite 0.67;
 use Business::PayPal::API ();
 
-our @ISA = qw(Business::PayPal::API);
-our $VERSION = '0.03';
-our $CVS_VERSION = '$Id: MassPay.pm,v 1.3 2009/07/28 18:00:59 scott Exp $';
+our @ISA       = qw(Business::PayPal::API);
 our @EXPORT_OK = qw( MassPay );
 
 sub MassPay {
@@ -22,20 +20,26 @@ sub MassPay {
     $args{MassPayItems} ||= [];
     $args{Version}      ||= "1.0";
 
-    my %types = ( EmailSubject => 'xs:string',
-                  Version      => 'xsd:string',
-#                  ReceiverType => 'ebl:ReceiverInfoCodeType',  ## EmailAddress | UserID
-                );
+    my %types = (
+        EmailSubject => 'xs:string',
+        Version      => 'xsd:string',
 
-    my %attr = ( Version => { xmlns => $self->C_xmlns_ebay },
-                 Amount  => { currencyID => $args{currencyID} }, );
+#                  ReceiverType => 'ebl:ReceiverInfoCodeType',  ## EmailAddress | UserID
+    );
+
+    my %attr = (
+        Version => { xmlns      => $self->C_xmlns_ebay },
+        Amount  => { currencyID => $args{currencyID} },
+    );
 
     ## mass pay item
-    my %mpi_type = ( ReceiverEmail => 'ebl:EmailAddressType',
-                     ReceiverID    => 'xs:string',
-                     Amount        => 'ebl:BasicAmountType',
-                     UniqueId      => 'xs:string',
-                     Note          => 'xs:string', );
+    my %mpi_type = (
+        ReceiverEmail => 'ebl:EmailAddressType',
+        ReceiverID    => 'xs:string',
+        Amount        => 'ebl:BasicAmountType',
+        UniqueId      => 'xs:string',
+        Note          => 'xs:string',
+    );
 
     my @recipients = @{ $args{MassPayItems} };
 
@@ -43,15 +47,19 @@ sub MassPay {
 
     for my $type ( sort keys %types ) {
         next unless $args{$type};
-        if( $attr{$type} ) {
-            push @masspay, SOAP::Data->name( $type => $args{$type} )->type($types{$type})->attr( { %{ $attr{$type} } } );
+        if ( $attr{$type} ) {
+            push @masspay,
+                SOAP::Data->name( $type => $args{$type} )
+                ->type( $types{$type} )->attr( { %{ $attr{$type} } } );
         }
         else {
-            push @masspay, SOAP::Data->name( $type => $args{$type} )->type($types{$type});
+            push @masspay,
+                SOAP::Data->name( $type => $args{$type} )
+                ->type( $types{$type} );
         }
     }
 
-    if( $args{ReceiverType} eq 'UserID' ) {
+    if ( $args{ReceiverType} eq 'UserID' ) {
         delete $mpi_type{ReceiverEmail};
     }
 
@@ -63,30 +71,36 @@ sub MassPay {
         my @rcpt = ();
         for my $type ( keys %mpi_type ) {
             next unless $mpi_type{$type};
-            if( $attr{$type} ) {
-                push @rcpt, SOAP::Data->name( $type => $rcpt->{$type} )->type($mpi_type{$type})->attr( { %{ $attr{$type} } } );
+            if ( $attr{$type} ) {
+                push @rcpt,
+                    SOAP::Data->name( $type => $rcpt->{$type} )
+                    ->type( $mpi_type{$type} )->attr( { %{ $attr{$type} } } );
             }
 
             else {
-                push @rcpt, SOAP::Data->name( $type => $rcpt->{$type} )->type($mpi_type{$type});
+                push @rcpt,
+                    SOAP::Data->name( $type => $rcpt->{$type} )
+                    ->type( $mpi_type{$type} );
             }
         }
 
-        push @masspay, SOAP::Data->name( MassPayItem => \SOAP::Data->value( @rcpt ) )->type("ns:MassPayRequestItemType");
+        push @masspay,
+            SOAP::Data->name( MassPayItem => \SOAP::Data->value( @rcpt ) )
+            ->type( "ns:MassPayRequestItemType" );
     }
 
-    my $request = SOAP::Data->name
-      ( MassPayRequest => \SOAP::Data->value( @masspay ) )
-        ->type("ns:MassPayRequestType");
+    my $request
+        = SOAP::Data->name( MassPayRequest => \SOAP::Data->value( @masspay ) )
+        ->type( "ns:MassPayRequestType" );
 
     my $som = $self->doCall( MassPayReq => $request )
-      or return;
+        or return;
 
     my $path = '/Envelope/Body/MassPayResponse';
 
     my %response = ();
-    unless( $self->getBasic($som, $path, \%response) ) {
-        $self->getErrors($som, $path, \%response);
+    unless ( $self->getBasic( $som, $path, \%response ) ) {
+        $self->getErrors( $som, $path, \%response );
         return %response;
     }
 
@@ -94,29 +108,39 @@ sub MassPay {
 }
 
 1;
-__END__
 
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Business::PayPal::API::MassPay - PayPal MassPay API
 
+=head1 VERSION
+
+version 0.72
+
 =head1 SYNOPSIS
 
-  use Business::PayPal::API::MassPay;
+    use Business::PayPal::API::MassPay;
 
-  ## see Business::PayPal::API documentation for parameters
-  my $pp = new Business::PayPal::API::MassPay ( ... );
+    ## see Business::PayPal::API documentation for parameters
+    my $pp = Business::PayPal::API::MassPay->new( ... );
 
-  my %response = $pp->MassPay( EmailSubject => "Here's your moola",
-                               MassPayItems => [ { ReceiverEmail => 'joe@somewhere.tld',
-                                                   Amount        => '95.44',
-                                                   Note          => 'Thanks for your stuff!' },
-                                                 { ReceiverEmail => 'bob@elsewhere.tld',
-                                                   Amount        => '15.31',
-                                                   Note          => 'We owe you one' }, ] );
-
- );
+    my %response = $pp->MassPay(
+        EmailSubject => "Here's your moola",
+        MassPayItems => [
+            {   ReceiverEmail => 'joe@somewhere.tld',
+                Amount        => '95.44',
+                Note          => 'Thanks for your stuff!'
+            },
+            {   ReceiverEmail => 'bob@elsewhere.tld',
+                Amount        => '15.31',
+                Note          => 'We owe you one'
+            },
+        ]
+    );
 
 =head1 DESCRIPTION
 
@@ -155,7 +179,7 @@ Example:
                                                UniqueId => "123456",
                                                Note => "Enjoy the money. Don't spend it all in one place." } ] );
 
-  unless( $resp{Ack} eq 'Success' ) {
+  unless( $resp{Ack} !~ /Success/ ) {
     die "Failed: " . $resp{Errors}[0]{LongMessage} . "\n";
   }
 
@@ -172,17 +196,34 @@ None by default.
 
 L<https://developer.paypal.com/en_US/pdf/PP_APIReference.pdf>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Scot Wiersdorf E<lt>scott@perlcode.orgE<gt>
+=over 4
+
+=item *
+
+Scott Wiersdorf <scott@perlcode.org>
+
+=item *
+
+Danny Hembree <danny@dynamical.org>
+
+=item *
+
+Bradley M. Kuhn <bkuhn@ebb.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 by Scott Wiersdorf
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.5 or,
-at your option, any later version of Perl 5 you may have available.
+This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+# ABSTRACT: PayPal MassPay API
+
