@@ -1,5 +1,5 @@
 package Business::PayPal::API::RefundTransaction;
-
+$Business::PayPal::API::RefundTransaction::VERSION = '0.72';
 use 5.008001;
 use strict;
 use warnings;
@@ -7,83 +7,97 @@ use warnings;
 use SOAP::Lite 0.67;
 use Business::PayPal::API ();
 
-our @ISA = qw(Business::PayPal::API);
-our $VERSION = '0.11';
-our $CVS_VERSION = '$Id: RefundTransaction.pm,v 1.4 2006/03/24 17:11:50 scott Exp $';
+our @ISA       = qw(Business::PayPal::API);
 our @EXPORT_OK = qw(RefundTransaction);
 
 sub RefundTransaction {
     my $self = shift;
     my %args = @_;
 
-    my %types = ( TransactionID => 'xs:string',
-		  RefundType    => '',                    ## Other | Full | Partial
-		  Amount        => 'ebl:BasicAmountType',
-		  Memo          => 'xs:string', );
+    my %types = (
+        TransactionID => 'xs:string',
+        RefundType    => '',                      ## Other | Full | Partial
+        Amount        => 'ebl:BasicAmountType',
+        Memo          => 'xs:string',
+    );
 
     $args{currencyID} ||= 'USD';
     $args{RefundType} ||= 'Full';
 
-    my @ref_trans = 
-      (
-       $self->version_req,
-       SOAP::Data->name( TransactionID => $args{TransactionID} )->type($types{TransactionID}),
-       SOAP::Data->name( RefundType => $args{RefundType} )->type($types{RefundType}),
-      );
+    my @ref_trans = (
+        $self->version_req,
+        SOAP::Data->name( TransactionID => $args{TransactionID} )
+            ->type( $types{TransactionID} ),
+        SOAP::Data->name( RefundType => $args{RefundType} )
+            ->type( $types{RefundType} ),
+    );
 
-    if( $args{RefundType} ne 'Full' && $args{Amount} ) {
-	push @ref_trans,
-	  SOAP::Data->name( Amount => $args{Amount} )
-	      ->type( $types{Amount} )
-		->attr( { currencyID => $args{currencyID} } )
+    if ( $args{RefundType} ne 'Full' && $args{Amount} ) {
+        push @ref_trans,
+            SOAP::Data->name( Amount => $args{Amount} )
+            ->type( $types{Amount} )
+            ->attr( { currencyID => $args{currencyID} } );
     }
 
     push @ref_trans,
-      SOAP::Data->name( Memo => $args{Memo} )->type( $types{Memo} )
-	  if $args{Memo};
+        SOAP::Data->name( Memo => $args{Memo} )->type( $types{Memo} )
+        if $args{Memo};
 
-    my $request = SOAP::Data->name
-      ( RefundTransactionRequest => \SOAP::Data->value( @ref_trans ) )
-	->type("ns:RefundTransactionRequestType");
+    my $request
+        = SOAP::Data->name(
+        RefundTransactionRequest => \SOAP::Data->value( @ref_trans ) )
+        ->type( "ns:RefundTransactionRequestType" );
 
     my $som = $self->doCall( RefundTransactionReq => $request )
-      or return;
+        or return;
 
     my $path = '/Envelope/Body/RefundTransactionResponse';
 
     my %response = ();
-    unless( $self->getBasic($som, $path, \%response) ) {
-        $self->getErrors($som, $path, \%response);
+    unless ( $self->getBasic( $som, $path, \%response ) ) {
+        $self->getErrors( $som, $path, \%response );
         return %response;
     }
 
-    $self->getFields($som, $path, \%response,
-                     { RefundTransactionID => 'RefundTransactionID',
-                       FeeRefundAmount     => 'FeeRefundAmount',
-                       NetRefundAmount     => 'NetRefundAmount',
-                       GrossRefundAmount   => 'GrossRefundAmount', }
-                    );
+    $self->getFields(
+        $som, $path,
+        \%response,
+        {   RefundTransactionID => 'RefundTransactionID',
+            FeeRefundAmount     => 'FeeRefundAmount',
+            NetRefundAmount     => 'NetRefundAmount',
+            GrossRefundAmount   => 'GrossRefundAmount',
+        }
+    );
 
     return %response;
 }
 
 1;
-__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Business::PayPal::API::RefundTransaction - PayPal RefundTransaction API
 
+=head1 VERSION
+
+version 0.72
+
 =head1 SYNOPSIS
 
-  use Business::PayPal::API::RefundTransaction;
+    use Business::PayPal::API::RefundTransaction;
 
-  ## see Business::PayPal::API documentation for parameters
-  my $pp = new Business::PayPal::API::RefundTransaction ( ... );
+    ## see Business::PayPal::API documentation for parameters
+    my $pp = Business::PayPal::API::RefundTransaction->new( ... );
 
-  my %response = $pp->RefundTransaction( TransactionID => $transid,
-                                         RefundType    => 'Full',
-                                         Memo          => "Please come again!" );
+    my %response = $pp->RefundTransaction(
+        TransactionID => $transid,
+        RefundType    => 'Full',
+        Memo          => "Please come again!"
+    );
 
 =head1 DESCRIPTION
 
@@ -123,7 +137,7 @@ Example:
                                      RefundType    => 'Partial',
                                      Amount        => '15.00', );
 
-  unless( $resp{Ack} ne 'Success' ) {
+  unless( $resp{Ack} !~ /Success/ ) {
       for my $error ( @{$response{Errors}} ) {
           warn "Error: " . $error->{LongMessage} . "\n";
       }
@@ -142,17 +156,34 @@ None by default.
 
 L<https://developer.paypal.com/en_US/pdf/PP_APIReference.pdf>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Scot Wiersdorf E<lt>scott@perlcode.orgE<gt>
+=over 4
+
+=item *
+
+Scott Wiersdorf <scott@perlcode.org>
+
+=item *
+
+Danny Hembree <danny@dynamical.org>
+
+=item *
+
+Bradley M. Kuhn <bkuhn@ebb.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Scott Wiersdorf
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.5 or,
-at your option, any later version of Perl 5 you may have available.
+This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+# ABSTRACT: PayPal RefundTransaction API
+
