@@ -1,5 +1,5 @@
 package Business::PayPal::API::VoidRequest;
-
+$Business::PayPal::API::VoidRequest::VERSION = '0.72';
 use 5.008001;
 use strict;
 use warnings;
@@ -7,68 +7,74 @@ use warnings;
 use SOAP::Lite 0.67;
 use Business::PayPal::API ();
 
-our @ISA = qw(Business::PayPal::API);
-our $VERSION = '0.12';
-our $CVS_VERSION = '$Id: VoidRequest.pm,v 1.2 2007/09/27 20:32:32 scott Exp $';
+our @ISA       = qw(Business::PayPal::API);
 our @EXPORT_OK = qw(DoVoidRequest);
 
 sub DoVoidRequest {
     my $self = shift;
     my %args = @_;
 
-    my %types = ( AuthorizationID => 'xs:string',
-                  Note            => 'xs:string', );
+    my %types = (
+        AuthorizationID => 'xs:string',
+        Note            => 'xs:string',
+    );
 
+    my @ref_trans = (
+        $self->version_req,
+        SOAP::Data->name( AuthorizationID => $args{AuthorizationID} )
+            ->type( $types{AuthorizationID} ),
+    );
 
-    my @ref_trans = 
-      (
-       $self->version_req,
-       SOAP::Data->name( AuthorizationID => $args{AuthorizationID} )->type($types{AuthorizationID}),
-      );
-
-    if ($args{Note}) {
-    push @ref_trans,
-      SOAP::Data->name( Note => $args{Note} )->type( $types{Note} )
-      if $args{Note};
+    if ( $args{Note} ) {
+        push @ref_trans,
+            SOAP::Data->name( Note => $args{Note} )->type( $types{Note} )
+            if $args{Note};
     }
-    my $request = SOAP::Data->name
-      ( DoVoidRequest => \SOAP::Data->value( @ref_trans ) )
-        ->type("ns:VoidRequestType");
+    my $request
+        = SOAP::Data->name(
+        DoVoidRequest => \SOAP::Data->value( @ref_trans ) )
+        ->type( "ns:VoidRequestType" );
 
     my $som = $self->doCall( DoVoidReq => $request )
-      or return;
+        or return;
 
     my $path = '/Envelope/Body/DoVoidResponse';
 
     my %response = ();
-    unless( $self->getBasic($som, $path, \%response) ) {
-        $self->getErrors($som, $path, \%response);
+    unless ( $self->getBasic( $som, $path, \%response ) ) {
+        $self->getErrors( $som, $path, \%response );
         return %response;
     }
 
-    $self->getFields($som, $path, \%response,
-                     { AuthorizationID => 'AuthorizationID' }
-                    );
+    $self->getFields( $som, $path, \%response,
+        { AuthorizationID => 'AuthorizationID' } );
 
     return %response;
 }
 
 1;
-__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Business::PayPal::API::VoidRequest - PayPal VoidRequest API
 
+=head1 VERSION
+
+version 0.72
+
 =head1 SYNOPSIS
 
-  use Business::PayPal::API::VoidRequest;
+    use Business::PayPal::API::VoidRequest;
 
-  ## see Business::PayPal::API documentation for parameters
-  my $pp = new Business::PayPal::API::VoidRequest ( ... );
+    # see Business::PayPal::API documentation for parameters
+    my $pp = Business::PayPal::API::VoidRequest->new( ... );
 
-  my %response = $pp->DoVoidRequest( AuthorizationID => $transid
-                                     Note            => "Please come again!" );
+    my %response = $pp->DoVoidRequest(
+        AuthorizationID => $transid Note => "Please come again!" );
 
 =head1 DESCRIPTION
 
@@ -101,7 +107,7 @@ Example:
   my %resp = $pp->DoVoidRequest( AuthorizationID => $trans_id,
                                  Note            => 'Sorry about that.' );
 
-  unless( $resp{Ack} ne 'Success' ) {
+  unless( $resp{Ack} !~ /Success/ ) {
       for my $error ( @{$response{Errors}} ) {
           warn "Error: " . $error->{LongMessage} . "\n";
       }
@@ -120,17 +126,34 @@ None by default.
 
 L<https://developer.paypal.com/en_US/pdf/PP_APIReference.pdf>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Danny Hembree E<lt>danny@dynamical.orgE<gt>
+=over 4
+
+=item *
+
+Scott Wiersdorf <scott@perlcode.org>
+
+=item *
+
+Danny Hembree <danny@dynamical.org>
+
+=item *
+
+Bradley M. Kuhn <bkuhn@ebb.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Danny Hembree
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.5 or,
-at your option, any later version of Perl 5 you may have available.
+This software is copyright (c) 2006-2015 by Scott Wiersdorf, Danny Hembree, Bradley M. Kuhn.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+# ABSTRACT:  PayPal VoidRequest API
+
